@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2013 Razor team
  * Authors:
@@ -86,7 +86,7 @@ void Actions::init()
         {
             QString shortcut;
             QString description;
-            bool enabled;
+            bool enabled = false;
             QDBusObjectPath path;
             if (getClientActionInfoById(I.key(), shortcut, description, enabled, path))
             {
@@ -104,7 +104,7 @@ void Actions::init()
         {
             QString shortcut;
             QString description;
-            bool enabled;
+            bool enabled = false;
             QString service;
             QDBusObjectPath path;
             QString interface;
@@ -126,7 +126,7 @@ void Actions::init()
         {
             QString shortcut;
             QString description;
-            bool enabled;
+            bool enabled = false;
             QString command;
             QStringList arguments;
             if (getCommandActionInfoById(I.key(), shortcut, description, enabled, command, arguments))
@@ -223,7 +223,7 @@ void Actions::do_actionAdded(qulonglong id)
 {
     QString shortcut;
     QString description;
-    bool enabled;
+    bool enabled = false;
     QString type;
     QString info;
     if (getActionById(id, shortcut, description, enabled, type, info))
